/**
 * Copyright (c) 2010 jolira. All rights reserved. This program and the accompanying materials are made available under
 * the terms of the GNU Public License 2.0 which is available at http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */
package com.google.code.joliratools.logdb.parser;

/**
 * Reports problems with the parsing process.
 * 
 * @author jfk
 * @date Sep 13, 2010 11:18:29 PM
 * @since 1.0
 */
public class ParseException extends Exception {
    private static final long serialVersionUID = 4015057671873406364L;
    private final int lineNumber;
    private final CharSequence raw;

    /**
     * Create a new exception.
     * 
     * @param cause
     *            the cause of the exception
     * @param lineNumber
     *            the line number of the line where the problem occurred
     * @param raw
     *            the raw record
     */
    public ParseException(final Throwable cause, final int lineNumber, final CharSequence raw) {
        super(cause);

        this.lineNumber = lineNumber;
        this.raw = raw;
    }

    /**
     * @return the line number
     */
    public int getLineNumber() {
        return lineNumber;
    }

    /**
     * @return the raw message
     */
    public CharSequence getRaw() {
        return raw;
    }
}
